"use strict";

exports.__esModule = true;
exports.createContext = createContext;

var _vue = require("vue");

/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
function createContext(options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      _options$strict = _options.strict,
      strict = _options$strict === void 0 ? true : _options$strict,
      _options$errorMessage = _options.errorMessage,
      errorMessage = _options$errorMessage === void 0 ? 'useContext: `context` is undefined. Seems you forgot to wrap component within the Provider' : _options$errorMessage,
      name = _options.name;
  var contextSymbol = Symbol(name + "Symbol");

  function Provider(payload) {
    (0, _vue.provide)(contextSymbol, payload);
  }

  function useContext() {
    var context = (0, _vue.inject)(contextSymbol, null);

    if (!context && strict) {
      throw new Error(errorMessage);
    }

    return context;
  }

  return [Provider, useContext];
}
//# sourceMappingURL=vue-utils.js.map