import { inject, provide } from 'vue';

/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
export function createContext(options) {
  if (options === void 0) {
    options = {};
  }

  var {
    strict = true,
    errorMessage = 'useContext: `context` is undefined. Seems you forgot to wrap component within the Provider',
    name
  } = options;
  var contextSymbol = Symbol(name + "Symbol");

  function Provider(payload) {
    provide(contextSymbol, payload);
  }

  function useContext() {
    var context = inject(contextSymbol, null);

    if (!context && strict) {
      throw new Error(errorMessage);
    }

    return context;
  }

  return [Provider, useContext];
}
//# sourceMappingURL=vue-utils.js.map